\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ucv-thesis}[2015/06/16 v1.0 UCV Thesis Class by Carlos Zapata]
\LoadClass[12pt,letterpaper,final,oneside,openany,onecolumn]{book}

%%%%%%%%%%%%%%%%%%%%%% Required Packages %%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[margin=3cm]{geometry}
\RequirePackage[spanish]{babel} 
\addto{\captionsspanish}{%
  \renewcommand{\bibname}{Referencias}
}
\RequirePackage[T1]{fontenc}
\RequirePackage[utf8x]{inputenc}
\RequirePackage{graphicx}
\RequirePackage{eulervm}
\RequirePackage{xcolor}
\RequirePackage{fancyvrb}
\RequirePackage{fancyhdr}
\RequirePackage{hyperref}
\RequirePackage{epstopdf}
\RequirePackage{makeidx}
\RequirePackage{titling}
\RequirePackage{multicol}
\RequirePackage[footnotesize]{subfigure}
\RequirePackage{quotchap}
\RequirePackage{palatino}
\RequirePackage[parfill]{parskip}
\RequirePackage{setspace} 
\RequirePackage{booktabs}
\RequirePackage{verbatim}
\RequirePackage{csquotes}
\RequirePackage{minted}
\RequirePackage{float}
\RequirePackage{rotating}
\RequirePackage{algorithm}
\RequirePackage{algorithmicx}
\usepackage{algorithm}% http://ctan.org/pkg/algorithms
\usepackage{algpseudocode}% http://ctan.org/pkg/algorithmicx
\floatname{algorithm}{Algoritmo}
\usemintedstyle{bw}

%%%%%%%%%%%%%%%%%%%%%% Style configuration %%%%%%%%%%%%%%%%%%%%%%

\definecolor{ucvblue}{rgb}{0.29,0.38,0.62}  % UCV blue RGB
\setlength{\parindent}{12pt}                % Identation
\setcounter{secnumdepth}{5}                 % Depth for bullets
\setcounter{tocdepth}{4}                    % TOC depth
\setlength{\headheight}{16pt}
\colorlet{chaptergrey}{ucvblue}             % Title color black
\renewcommand*\sectfont{\color{black}}      % Title font color
\renewcommand{\headrulewidth}{0.0pt}        % No heading line
\hypersetup{
    colorlinks = false,
    allbordercolors = {white}
}
 
%%%%%%%%%%%%%%%%%%%%%% Definitions %%%%%%%%%%%%%%%%%%%%%%

% Department
\def 
\department#1{
    \gdef\@department{
        #1
    }
}

% School
\def
\school#1{
    \gdef\@school{
        #1
    }
}

% Faculty
\def
\faculty#1{
    \gdef\@faculty{
        #1
    }
}

% University
\def 
\university#1{
    \gdef
    \@university{
        #1
    }
}

% Degree year
\def
\degreeyear#1{
    \gdef
    \@degreeyear{
        #1
    }
}

% Degree month
\def
\degreemonth#1{
    \gdef
    \@degreemonth{
        #1
    }
}

% Advisor
\def 
\advisor#1 {
    \gdef 
    \@advisor{
        #1
    }
}

% Authors
\def 
\author#1{
    \gdef
    \@author{
        #1
    }
}

% Degree
\def 
\degree#1{
    \gdef 
    \@degree{
        #1
    }
}

% Title
\def 
\title#1{
    \gdef 
    \@title{
        #1
    }
}

%%%%%%%%%%%%%%%%%%%%%% New Commands %%%%%%%%%%%%%%%%%%%%%%

\renewcommand{\maketitle} {
    \thispagestyle{empty}
    
    \begin{figure}[t]
    	\centering
    	\includegraphics[height=0.15\textwidth]{figures/ucv-logo.png}
    \end{figure}

    \begin{center}
        \@university \\
        \@faculty    \\
        \@school     \\
    \end{center}

    \vspace{2.5cm}
    \begin{center}
      \large{\textbf{\@title}}
    \end{center}

    \vspace{4.2cm}
    
    \vspace{1.0cm}
    \begin{center}
        Trabajo Especial de Grado presentado ante la Ilustre \\ 
        Universidad Central de Venezuela por el \\
        Br. \@author\\
        para optar al título de Licenciado en Computación \\
    \end{center}
    
    \vspace{1.0cm}
    \begin{center}
      Tutor \\ 
      \@advisor
    \end{center}

    \vspace{2.0cm}
    \begin{center}
      Caracas,\@degreemonth del\@degreeyear
    \end{center}
}

% Abstract
\newcommand{\abstract} {
    \newpage
    \phantomsection
    \addcontentsline{toc}{chapter}{Resumen}
    \chapter*{Resumen}
    \markboth{Resumen}{Resumen}
    \pagenumbering{roman}
    \setcounter{page}{1}
    \input{frontmatter/abstract}
    \lhead{\textit{\MakeUppercase{\leftmark}}} \rhead{}
    \cfoot{\thepage}
}

% Dedication
\newcommand{\dedication}{
    \newpage
    \phantomsection
    \addcontentsline{toc}{chapter}{Dedicatoria}
    \chapter*{Dedicatoria}
    \markboth{Dedicatoria}{Dedicatoria}
	\pagestyle{fancy}
	\thispagestyle{fancy} 
	\vspace*{\fill}
	\sc 
	\noindent 
	\markboth{}{}
	\textit{\input{frontmatter/dedication}}
	\vspace*{\fill} \newpage \rm
}

% Acknowledgments
\newcommand{\acknowledgments} {
    \newpage
    \phantomsection
    \addcontentsline{toc}{chapter}{Agradecimientos}
    \chapter*{Agradecimientos}
    \markboth{Agradecimientos}{Agradecimientos}
    \input{frontmatter/acknowledgments}
    \lhead{\textit{\MakeUppercase{\leftmark}}} \rhead{}
    \cfoot{\thepage}
}

% Introduction
\newcommand{\introduction}{
    \newpage
    \phantomsection
    \addcontentsline{toc}{chapter}{Introducción}
    \chapter*{Introducción}
    \markboth{Introducción}{Introducción}
    \input{frontmatter/introduction}
    \lhead{\textit{\MakeUppercase{\leftmark}}} \rhead{}
    \cfoot{\thepage}
}

% Background
\newcommand{\background}{
    \addcontentsline{toc}{chapter}{Antecedentes}
    \chapter*{Antecedentes}
    \markboth{Antecedentes}{Antecedentes}
    \input{mainmatter/background}
    \lhead{\textit{\MakeUppercase{\leftmark}}} \rhead{}
    \cfoot{\thepage}
}

% Future work
\newcommand{\futurework} {
    \addcontentsline{toc}{chapter}{Conclusiones y trabajos futuros}
    \chapter*{Conclusiones y trabajos futuros}
    \markboth{Conclusiones y trabajos futuros}{Conclusiones y trabajos futuros}
    \input{backmatter/futurework}
    \lhead{\textit{\MakeUppercase{\leftmark}}} \rhead{}
    \cfoot{\thepage}
}

% Glossary
\renewcommand{\glossary}{
    \addcontentsline{toc}{chapter}{Glosario}
    \chapter*{Glosario}
    \markboth{Glosario}{Glosario}
    \input{backmatter/glossary}
    \lhead{\textit{\MakeUppercase{\leftmark}}} \rhead{}
    \cfoot{\thepage}
}

% References

\newcommand{\References}{
    \addcontentsline{toc}{chapter}{Referencias}
    \bibliographystyle{IEEE}
    \bibliography{backmatter/bibliography}
    \nocite{*}
}


% Código
\renewcommand\listingscaption{Código}
\renewcommand\listoflistingscaption{Lista de códigos}